@@ -197,6 +197,8 @@ class ModelInstance:
         # get chat history interactions with pagination
         url = BASE_URL + f'models/{self.model_id}/instances/{self.instance_id}/chat_history'
         response = _format_http_response(requests.get(url, headers=HEADERS))
+        print('get_chat_history debugging')
+        print(url)
         print(response)
         self.chat_history.extend(response['body']['interactions'])
         while 'next_page_token' in response:
